# Credits

## Contributors

* Pascal Grobecker <pgrobecker@illumina.com>
  * Developed prototype replicating method described in [Ryan et al. (2023)](https://doi.org/10.1038/s41375-022-01806-8)
  * Defined specifications for required features
  * Validated releases

* Stefano Berri <sberri@illumina.com>
  * Designed architecture of the codebase
  * Wrote unit tests to guide the refactoring of original prototype
  * Contributed with code to add features and fix bugs

* Kai Jie Chow <kchow@illumina.com>
  * Set up testing automation
  * Contributed with code to add features and fix bugs

* Martina Mijuskovic <mmijuskovic@illumina.com>
  * Provided guidance and insights on the tool scope and features
